@@ -1,13 +1,18 @@
 package Bencher::Scenario::SetOperationModules;
 
-our $DATE = '2015-11-19'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 our $scenario = {
+    modules => {
+        'List::MoreUtils' => {
+            version => '0.407', # singleton() is available from this version
+        },
+    },
     participants => [
         # UNION
         {
@@ -249,7 +254,7 @@ Bencher::Scenario::SetOperationModules - Benchmark Perl set operation (union, in
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2015-11-19.
+This document describes version 0.07 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2015-11-29.
 
 =head1 SYNOPSIS
 
